@@ -44,9 +44,15 @@ class Forum(object):
     def add_post(self, collection_id, folder, message, username):
         return retry(self, self._add_post, collection_id, folder, message, username)
     
+    def _category(self, collection_id):
+        return self.syncano.collection_get_one(self.project_id, collection_id)
+    
+    def category(self, collection_id):
+        return retry(self, self._category, collection_id)
+    
     def _categories(self):
         projects = self.syncano.collection_get(self.project_id)
-        return projects
+        return projects    
     
     def categories(self):
         return retry(self, self._categories)
@@ -59,16 +65,16 @@ class Forum(object):
         return retry(self, self._topics, collection_id)
     
     def _posts(self, collection_id, folder, since_id, max_id, order, limit):
-        posts = self.syncano.data.get(self.project_id, collection_id, folders=[folder],
+        posts = self.syncano.data.get(self.project_id, collection_id, folders=folder,
                                       since_id=since_id, max_id=max_id, order=order, limit=limit)
         return posts
-    def posts(self, collection_id, folder, since_id, max_id, order, limit=20):
-        return list(retry(self, self._posts, collection_id, folder, since_id, max_id, order, limit))
+    def posts(self, collection_id, folder, since_id, max_id, order, limit=20, posts_formater=None):
+        posts = list(retry(self, self._posts, collection_id, folder, since_id, max_id, order, limit))
+        return posts if not posts_formater else posts_formater(posts)
     
-    
-    def get_pages(self, collection_id, folder, since_id, page):
-        first_page = self.posts(collection_id, folder, None, None, 'ASC')
-        last_page = self.posts(collection_id, folder, None, None, 'DESC')
+    def get_pages(self, collection_id, folder, since_id, page, posts_formater=None):
+        first_page = self.posts(collection_id, folder, None, None, 'ASC', posts_formater=posts_formater)
+        last_page = self.posts(collection_id, folder, None, None, 'DESC', posts_formater=posts_formater)
         count = self.syncano.data_count(self.project_id, collection_id, folders=folder).count
         last_page = last_page[:count % 20 or 20]
         result = dict(first=[1, None],
@@ -77,8 +83,8 @@ class Forum(object):
         if count <= 20:
             result['posts'] = first_page
         else:
-            posts_before = self.posts(collection_id, folder, None, since_id-1 if since_id else None, 'DESC', 40)[::-1]
-            posts_next = self.posts(collection_id, folder, since_id-1 if since_id else None, None, 'ASC', 60)
+            posts_before = self.posts(collection_id, folder, None, since_id-1 if since_id else None, 'DESC', 40, posts_formater=posts_formater)[::-1]
+            posts_next = self.posts(collection_id, folder, since_id-1 if since_id else None, None, 'ASC', 60, posts_formater=posts_formater)
             result['last'] = [int(math.floor(float(count)/20)), last_page[-1].id]
             result['posts'] = posts_next[:20]
             tpage = page - 1
